pub struct LogDiagnosticsState { /* private fields */ }Expand description
State used by the LogDiagnosticsPlugin
Implementations
Sourceimpl LogDiagnosticsState
impl LogDiagnosticsState
Sourcepub fn set_timer_duration(&mut self, duration: Duration)
pub fn set_timer_duration(&mut self, duration: Duration)
Sets a new duration for the log timer
Sourcepub fn add_filter(&mut self, diagnostic_path: DiagnosticPath) -> bool
pub fn add_filter(&mut self, diagnostic_path: DiagnosticPath) -> bool
Add a filter to the log state, returning true if the DiagnosticPath
was not present
Sourcepub fn extend_filter(&mut self, iter: impl IntoIterator<Item = DiagnosticPath>)
pub fn extend_filter(&mut self, iter: impl IntoIterator<Item = DiagnosticPath>)
Extends the filter of the log state with multiple DiagnosticPaths
Sourcepub fn remove_filter(&mut self, diagnostic_path: &DiagnosticPath) -> bool
pub fn remove_filter(&mut self, diagnostic_path: &DiagnosticPath) -> bool
Removes a filter from the log state, returning true if it was present
Sourcepub fn clear_filter(&mut self)
pub fn clear_filter(&mut self)
Clears the filters of the log state
Sourcepub fn enable_filtering(&mut self)
pub fn enable_filtering(&mut self)
Enables filtering with empty filters
Sourcepub fn disable_filtering(&mut self)
pub fn disable_filtering(&mut self)
Disables filtering